package com.ruoyi.poi.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.*;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.Result;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.poi.domain.PoiBookshelf;
import com.ruoyi.poi.domain.req.PoiBookshelfQueryReq;
import com.ruoyi.poi.domain.req.PoiBookshelfSaveReq;
import com.ruoyi.poi.domain.req.PoiBookshelfEditReq;
import com.ruoyi.poi.service.PoiBookshelfService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * POI信息Controller
 *
 * @author ruoyi
 * @date 2025-01-03
 */
@Api(tags = "POI信息")
@RestController
@RequestMapping("/poi/bookshelf")
public class PoiBookshelfController extends BaseController {
    @Autowired
    private PoiBookshelfService poiBookshelfService;

    /**
     * 查询POI信息列表
     */
    @ApiOperation("获取POI信息列表")
    @PreAuthorize("@ss.hasPermi('poi:bookshelf:list')")
    @GetMapping("/list")
    public Result<TableDataInfo<PoiBookshelf>> list(PoiBookshelfQueryReq poiBookshelfQueryReq) {
        startPage();
        List<PoiBookshelf> list = poiBookshelfService.list(PoiBookshelf.queryBuild(poiBookshelfQueryReq));
        return getDataTable(list);
    }

    /**
     * 导出POI信息列表
     */
    @ApiOperation("导出POI信息列表")
    @PreAuthorize("@ss.hasPermi('poi:bookshelf:export')")
    @Log(title = "POI信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PoiBookshelf poiBookshelf) {
        List<PoiBookshelf> list = poiBookshelfService.list(poiBookshelf);
        ExcelUtil<PoiBookshelf> util = new ExcelUtil<PoiBookshelf>(PoiBookshelf.class);
        util.exportExcel(response, list, "POI信息数据");
    }

    /**
     * 获取POI信息详细信息
     */
    @ApiOperation("获取POI信息详细信息")
    @PreAuthorize("@ss.hasPermi('poi:bookshelf:query')")
    @GetMapping(value = "/{poiId}")
    @ApiImplicitParam(name = "poiId", value = "poiId", required = true, dataType = "String", paramType = "path", dataTypeClass = String.class)
    public Result<PoiBookshelf> getInfo(@PathVariable("poiId") String poiId) {
        return Result.success(poiBookshelfService.getById(poiId));
    }

    /**
     * 新增POI信息
     */
    @PreAuthorize("@ss.hasPermi('poi:bookshelf:add')")
    @Log(title = "POI信息", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增POI信息")
    public Result<String> add(@RequestBody PoiBookshelfSaveReq poiBookshelfSaveReq) {
        return toAjax(poiBookshelfService.save(PoiBookshelf.saveBuild(poiBookshelfSaveReq)));
    }

    /**
     * 修改POI信息
     */
    @PreAuthorize("@ss.hasPermi('poi:bookshelf:edit')")
    @Log(title = "POI信息", businessType = BusinessType.UPDATE)
    @PutMapping("/{poiId}")
    @ApiOperation("修改POI信息")
    public Result<String> edit(@PathVariable String poiId, @RequestBody PoiBookshelfEditReq poiBookshelfEditReq) {
        return toAjax(poiBookshelfService.updateById(PoiBookshelf.editBuild(poiId,poiBookshelfEditReq)));
    }

    /**
     * 删除POI信息
     */
    @PreAuthorize("@ss.hasPermi('poi:bookshelf:remove')")
    @Log(title = "POI信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{poiIds}")
    @ApiOperation("删除POI信息")
    @ApiImplicitParam(name = "poiId", value = "poiId", required = true, dataType = "String", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<String> poiIds) {
        return toAjax(poiBookshelfService.removeBatchByIds(poiIds));
    }
}
