package com.ruoyi.web.controller.poi;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.*;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.Result;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.poi.domain.PoiCategory;
import com.ruoyi.poi.domain.req.PoiCategoryQueryReq;
import com.ruoyi.poi.domain.req.PoiCategorySaveReq;
import com.ruoyi.poi.domain.req.PoiCategoryEditReq;
import com.ruoyi.poi.service.PoiCategoryService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * POI 分类Controller
 *
 * @author sun
 * @date 2025-01-03
 */
@Api(tags = "POI 分类")
@RestController
@RequestMapping("/poi/category")
public class PoiCategoryController extends BaseController {
    @Autowired
    private PoiCategoryService poiCategoryService;

    /**
     * 查询POI 分类列表
     */
    @ApiOperation("获取POI 分类列表")
    @PreAuthorize("@ss.hasPermi('poi:category:list')")
    @GetMapping("/list")
    public Result<TableDataInfo<PoiCategory>> list(PoiCategoryQueryReq poiCategoryQueryReq) {
        startPage();
        List<PoiCategory> list = poiCategoryService.list(PoiCategory.queryBuild(poiCategoryQueryReq));
        return getDataTable(list);
    }

    /**
     * 导出POI 分类列表
     */
    @ApiOperation("导出POI 分类列表")
    @PreAuthorize("@ss.hasPermi('poi:category:export')")
    @Log(title = "POI 分类", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PoiCategory poiCategory) {
        List<PoiCategory> list = poiCategoryService.list(poiCategory);
        ExcelUtil<PoiCategory> util = new ExcelUtil<PoiCategory>(PoiCategory.class);
        util.exportExcel(response, list, "POI 分类数据");
    }

    /**
     * 获取POI 分类详细信息
     */
    @ApiOperation("获取POI 分类详细信息")
    @PreAuthorize("@ss.hasPermi('poi:category:query')")
    @GetMapping(value = "/{id}")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "String", paramType = "path", dataTypeClass = String.class)
    public Result<PoiCategory> getInfo(@PathVariable("id") String id) {
        return Result.success(poiCategoryService.getById(id));
    }

    /**
     * 新增POI 分类
     */
    @PreAuthorize("@ss.hasPermi('poi:category:add')")
    @Log(title = "POI 分类", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增POI 分类")
    public Result<String> add(@RequestBody PoiCategorySaveReq poiCategorySaveReq) {
        return toAjax(poiCategoryService.save(PoiCategory.saveBuild(poiCategorySaveReq)));
    }

    /**
     * 修改POI 分类
     */
    @PreAuthorize("@ss.hasPermi('poi:category:edit')")
    @Log(title = "POI 分类", businessType = BusinessType.UPDATE)
    @PutMapping("/{id}")
    @ApiOperation("修改POI 分类")
    public Result<String> edit(@PathVariable String id, @RequestBody PoiCategoryEditReq poiCategoryEditReq) {
        return toAjax(poiCategoryService.updateById(PoiCategory.editBuild(id,poiCategoryEditReq)));
    }

    /**
     * 删除POI 分类
     */
    @PreAuthorize("@ss.hasPermi('poi:category:remove')")
    @Log(title = "POI 分类", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除POI 分类")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "String", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<String> ids) {
        return toAjax(poiCategoryService.removeBatchByIds(ids));
    }
}
