package com.ruoyi.poi.domain;

import java.util.Date;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.AllArgsConstructor;
import lombok.experimental.SuperBuilder;
import io.swagger.annotations.*;
import com.ruoyi.common.annotation.Excel;
import com.ruoyi.poi.domain.req.PoiCategoryQueryReq;
import com.ruoyi.poi.domain.req.PoiCategorySaveReq;
import com.ruoyi.poi.domain.req.PoiCategoryEditReq;
import com.ruoyi.common.core.domain.BaseEntity;

/**
 * POI 分类对象 poi_category
 *
 * @author sun
 * @date 2025-01-03
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@TableName("poi_category")
@EqualsAndHashCode(callSuper = true)
@ApiModel(value = "PoiCategory", description = "POI 分类")
public class PoiCategory extends BaseEntity {

    private static final long serialVersionUID = 1L;

    /** 分类ID */
    @TableId(value = "id",type = IdType.AUTO)
    @ApiModelProperty(name = "分类ID", value = "分类ID")
    private String id;

    /** 分类名称 */
    @Excel(name = "分类名称")
    @ApiModelProperty(name = "分类名称", value = "分类名称")
    private String name;

    /** 分类图片 */
    @Excel(name = "分类图片")
    @ApiModelProperty(name = "分类图片", value = "分类图片")
    private String image;

    /** 状态:0=隐藏,1=正常,2=推荐 */
    @Excel(name = "状态:0=隐藏,1=正常,2=推荐")
    @ApiModelProperty(name = "状态:0=隐藏,1=正常,2=推荐", value = "状态:0=隐藏,1=正常,2=推荐")
    private String status;

    /** 权重 */
    @Excel(name = "权重")
    @ApiModelProperty(name = "权重", value = "权重")
    private Long weigh;

    /** 添加时间 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "添加时间", width = 30, dateFormat = "yyyy-MM-dd")
    @ApiModelProperty(name = "添加时间", value = "添加时间")
    private Date createdTime;

    /** 更新时间 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "更新时间", width = 30, dateFormat = "yyyy-MM-dd")
    @ApiModelProperty(name = "更新时间", value = "更新时间")
    private Date updatedTime;

    /** 删除时间 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "删除时间", width = 30, dateFormat = "yyyy-MM-dd")
    @ApiModelProperty(name = "删除时间", value = "删除时间")
    private Date deletedTime;

    /**
    * 查询构造器
    */
    public static PoiCategory queryBuild( PoiCategoryQueryReq poiCategoryQueryReq){
        return PoiCategory.builder()
                .name(poiCategoryQueryReq.getName())
                .image(poiCategoryQueryReq.getImage())
                .status(poiCategoryQueryReq.getStatus())
                .weigh(poiCategoryQueryReq.getWeigh())
                .createdTime(poiCategoryQueryReq.getCreatedTime())
                .updatedTime(poiCategoryQueryReq.getUpdatedTime())
                .deletedTime(poiCategoryQueryReq.getDeletedTime())
                .build();
    }

    /**
    * 添加构造器
    */
    public static PoiCategory saveBuild(PoiCategorySaveReq poiCategorySaveReq){
        return PoiCategory.builder()
                .name(poiCategorySaveReq.getName())
                .image(poiCategorySaveReq.getImage())
                .status(poiCategorySaveReq.getStatus())
                .weigh(poiCategorySaveReq.getWeigh())
                .createdTime(poiCategorySaveReq.getCreatedTime())
                .updatedTime(poiCategorySaveReq.getUpdatedTime())
                .deletedTime(poiCategorySaveReq.getDeletedTime())
                .build();
    }

    /**
    * 修改构造器
    */
    public static PoiCategory editBuild(String id, PoiCategoryEditReq poiCategoryEditReq){
        return PoiCategory.builder()
            .id(id)
                .name(poiCategoryEditReq.getName())
                .image(poiCategoryEditReq.getImage())
                .status(poiCategoryEditReq.getStatus())
                .weigh(poiCategoryEditReq.getWeigh())
                .createdTime(poiCategoryEditReq.getCreatedTime())
                .updatedTime(poiCategoryEditReq.getUpdatedTime())
                .deletedTime(poiCategoryEditReq.getDeletedTime())
                .build();
    }

}
